==> geopsypack-src-3.3.6.tar.gz: geopsypack-src-3.3.6/gplivemodel/src/DispersionGridThread.h <==
/***************************************************************************
**
**  This file is part of gplivemodel.
**
**  gplivemodel is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  gplivemodel is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2008-10-16
**  Copyright: 2008-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef DISPERSIONGRIDTHREAD_H
#define DISPERSIONGRIDTHREAD_H

#include <QGpCoreWave.h>
#include <SciFigs.h>

#include "Seismic1DThread.h"

class DispersionThread;

class DispersionGridThread : public Seismic1DThread
{
  Q_OBJECT
public:
  DispersionGridThread(QObject * parent=nullptr);
  DispersionGridThread(const DispersionGridThread& o);
  ~DispersionGridThread();

  virtual ResultsThread * clone() const {return new DispersionGridThread(*this);}

  virtual void initResultsGraphs(GraphicSheet * sheet);
  virtual void initResultsGraphs(const ResultsThread& o) {CurvesThread::initResultsGraphs(o);}
  virtual bool setParameters(int& argc, char ** argv);

  virtual void setLimits();
  virtual void resultsDeepUpdate();
private:
  virtual void start(QList<GeophysicalModel *> models);
  void run(GeophysicalModel *) {}

  LiveGridLayer * _layer;

  double _xMinRange, _xMaxRange;
  double _vMinRange, _vMaxRange;
  Mode::Polarization _polarization;
};

#endif // DISPERSIONGRIDTHREAD_H

==> geopsypack-src-3.5.1.tar.gz: geopsypack-src-3.5.1/gplivemodel/src/DispersionGridThread.h <==
/***************************************************************************
**
**  This file is part of gplivemodel.
**
**  gplivemodel is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  gplivemodel is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2008-10-16
**  Copyright: 2008-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef DISPERSIONGRIDTHREAD_H
#define DISPERSIONGRIDTHREAD_H

#include <QGpCoreWave.h>
#include <SciFigs.h>

#include "Seismic1DThread.h"

class DispersionThread;

class DispersionGridThread : public Seismic1DThread
{
  Q_OBJECT
public:
  DispersionGridThread(QObject * parent=nullptr);
  DispersionGridThread(const DispersionGridThread& o);
  ~DispersionGridThread();

  ResultsThread * clone() const {return new DispersionGridThread(*this);}

  void initResultsGraphs(GraphicSheet * sheet);
  void initResultsGraphs(const ResultsThread& o) {CurvesThread::initResultsGraphs(o);}
  bool setParameters(int& argc, char ** argv);

  void setLimits();
  void resultsDeepUpdate();
private:
  void start(QList<GeophysicalModel *> models);
  void run(GeophysicalModel *) {}

  LiveGridLayer * _layer;

  double _xMinRange, _xMaxRange;
  double _vMinRange, _vMaxRange;
  Mode::Polarization _polarization;
};

#endif // DISPERSIONGRIDTHREAD_H
